@@ -24,11 +24,19 @@ import org.gradle.plugins.ide.internal.resolver.model.IdeProjectDependency;
 
 class ModuleDependencyBuilder {
     public ModuleDependency create(IdeProjectDependency dependency, String scope) {
+        ModuleDependency moduleDependency = new ModuleDependency(determineProjectName(dependency), scope);
+        moduleDependency.setGradlePath(dependency.getProjectPath());
+        return moduleDependency;
+    }
+
+    private String determineProjectName(IdeProjectDependency dependency) {
         Project project = dependency.getProject();
-        if (project.getPlugins().hasPlugin(IdeaPlugin.class)) {
-            return new ModuleDependency(((IdeaModel) project.getExtensions().getByName("idea")).getModule().getName(), scope);
+        if (project == null) {
+            return dependency.getModuleName();
+        } else if (project.getPlugins().hasPlugin(IdeaPlugin.class)) {
+            return ((IdeaModel) project.getExtensions().getByName("idea")).getModule().getName();
         } else {
-            return new ModuleDependency(project.getName(), scope);
+            return project.getName();
         }
     }
 }
