@@ -15,9 +15,12 @@
  */
 package org.gradle.integtests.fixtures.executer;
 
+import com.google.common.io.CharSource;
 import org.apache.commons.collections.CollectionUtils;
 import org.gradle.api.Action;
+import org.gradle.api.UncheckedIOException;
 import org.gradle.util.TextUtil;
+import org.hamcrest.core.StringContains;
 
 import java.io.BufferedReader;
 import java.io.IOException;
@@ -25,11 +28,14 @@ import java.io.StringReader;
 import java.util.*;
 import java.util.regex.Pattern;
 
+import static org.gradle.launcher.daemon.client.DefaultDaemonConnector.STARTING_DAEMON_MESSAGE;
 import static org.gradle.util.TextUtil.normaliseLineSeparators;
-import static org.hamcrest.Matchers.*;
+import static org.hamcrest.Matchers.equalTo;
+import static org.hamcrest.Matchers.hasItem;
 import static org.junit.Assert.assertThat;
 
 public class OutputScrapingExecutionResult implements ExecutionResult {
+    static final Pattern STACK_TRACE_ELEMENT = Pattern.compile("\\s+(at\\s+)?[\\w.$_]+\\.[\\w$_ =\\+\'-]+\\(.+?\\)");
     private final String output;
     private final String error;
 
@@ -40,23 +46,65 @@ public class OutputScrapingExecutionResult implements ExecutionResult {
     private final Pattern taskPattern = Pattern.compile("(:\\S+?(:\\S+?)*)((\\s+SKIPPED)|(\\s+UP-TO-DATE)|(\\s+FAILED)|(\\s*))");
 
     public OutputScrapingExecutionResult(String output, String error) {
-        this.output = output;
-        this.error = error;
+        this.output = TextUtil.normaliseLineSeparators(output);
+        this.error = TextUtil.normaliseLineSeparators(error);
     }
 
     public String getOutput() {
         return output;
     }
 
+    @Override
+    public String getNormalizedOutput() {
+        return normalize(output);
+    }
+
+    public static String normalize(String output) {
+        StringBuilder result = new StringBuilder();
+        List<String> lines;
+        try {
+            lines = CharSource.wrap(output).readLines();
+        } catch (IOException e) {
+            throw new UncheckedIOException(e);
+        }
+        int i = 0;
+        while (i < lines.size()) {
+            String line = lines.get(i);
+            if (line.contains("Support for running Gradle using Java 6 has been deprecated and will be removed in Gradle 3.0")) {
+                // Assume running build on Java 6, skip over stack trace and ignore
+                i++;
+                while (i < lines.size() && STACK_TRACE_ELEMENT.matcher(lines.get(i)).matches()) {
+                    i++;
+                }
+            } else if (line.contains("is deprecated and will be removed in tooling API version 3.0. You should upgrade your Gradle build to use Gradle 1.2 or later.")) {
+                // Assume you are in a cross-version integration test and want to strip this line.
+                i++;
+            } else if (line.contains(STARTING_DAEMON_MESSAGE)) {
+                // Assume running using the daemon, ignore
+                i++;
+            } else if (i == lines.size() - 1 && line.matches("Total time: [\\d\\.]+ secs")) {
+                result.append("Total time: 1 secs");
+                result.append('\n');
+                i++;
+            } else {
+                result.append(line);
+                result.append('\n');
+                i++;
+            }
+        }
+
+        return result.toString();
+    }
+
     public ExecutionResult assertOutputEquals(String expectedOutput, boolean ignoreExtraLines, boolean ignoreLineOrder) {
         SequentialOutputMatcher matcher = ignoreLineOrder ? new AnyOrderOutputMatcher() : new SequentialOutputMatcher();
-        matcher.assertOutputMatches(expectedOutput, getOutput(), ignoreExtraLines);
+        matcher.assertOutputMatches(expectedOutput, getNormalizedOutput(), ignoreExtraLines);
         return this;
     }
 
     @Override
     public ExecutionResult assertOutputContains(String expectedOutput) {
-        assertThat("Substring not found in build output", TextUtil.normaliseLineSeparators(getOutput()), org.hamcrest.core.StringContains.containsString(normaliseLineSeparators(expectedOutput)));
+        assertThat("Substring not found in build output", getOutput(), StringContains.containsString(normaliseLineSeparators(expectedOutput)));
         return this;
     }
 
@@ -74,12 +122,6 @@ public class OutputScrapingExecutionResult implements ExecutionResult {
         return this;
     }
 
-    public ExecutionResult assertTaskNotExecuted(String taskPath) {
-        Set<String> tasks = new HashSet<String>(getExecutedTasks());
-        assertThat(String.format("Expected task %s found in process output:%n%s", taskPath, getOutput()), tasks, not(hasItem(taskPath)));
-        return this;
-    }
-
     public Set<String> getSkippedTasks() {
         return new HashSet<String>(grepTasks(skippedTaskPattern));
     }
