@@ -17,23 +17,19 @@
 package org.gradle.plugins.javascript.jshint;
 
 import com.google.gson.GsonBuilder;
-import org.gradle.api.Action;
 import org.gradle.api.GradleException;
 import org.gradle.api.UncheckedIOException;
 import org.gradle.api.file.FileCollection;
 import org.gradle.api.logging.LogLevel;
 import org.gradle.api.logging.Logger;
 import org.gradle.api.tasks.*;
-import org.gradle.internal.Factory;
+import org.gradle.plugins.javascript.jshint.internal.JsHintProtocol;
 import org.gradle.plugins.javascript.jshint.internal.JsHintResult;
 import org.gradle.plugins.javascript.jshint.internal.JsHintSpec;
 import org.gradle.plugins.javascript.jshint.internal.JsHintWorker;
-import org.gradle.plugins.javascript.rhino.worker.RhinoWorkerHandle;
 import org.gradle.plugins.javascript.rhino.worker.RhinoWorkerHandleFactory;
-import org.gradle.plugins.javascript.rhino.worker.RhinoWorkerSpec;
 import org.gradle.plugins.javascript.rhino.worker.internal.DefaultRhinoWorkerHandleFactory;
-import org.gradle.process.JavaExecSpec;
-import org.gradle.process.internal.WorkerProcessBuilder;
+import org.gradle.process.internal.worker.WorkerProcessFactory;
 
 import javax.inject.Inject;
 import java.io.File;
@@ -51,7 +47,7 @@ public class JsHint extends SourceTask {
     private Object jsonReport;
 
     @Inject
-    protected Factory<WorkerProcessBuilder> getWorkerProcessBuilderFactory() {
+    protected WorkerProcessFactory getWorkerProcessBuilderFactory() {
         throw new UnsupportedOperationException();
     }
 
@@ -96,18 +92,14 @@ public class JsHint extends SourceTask {
         RhinoWorkerHandleFactory handleFactory = new DefaultRhinoWorkerHandleFactory(getWorkerProcessBuilderFactory());
 
         LogLevel logLevel = getProject().getGradle().getStartParameter().getLogLevel();
-        RhinoWorkerHandle<JsHintResult, JsHintSpec> rhinoHandle = handleFactory.create(getRhinoClasspath(), createWorkerSpec(), logLevel, new Action<JavaExecSpec>() {
-            public void execute(JavaExecSpec javaExecSpec) {
-                javaExecSpec.setWorkingDir(getProject().getProjectDir());
-            }
-        });
+        JsHintProtocol worker = handleFactory.create(getRhinoClasspath(), JsHintProtocol.class, JsHintWorker.class, logLevel, getProject().getProjectDir());
 
         JsHintSpec spec = new JsHintSpec();
         spec.setSource(getSource().getFiles()); // flatten because we need to serialize
         spec.setEncoding(getEncoding());
         spec.setJsHint(getJsHint().getSingleFile());
 
-        JsHintResult result = rhinoHandle.process(spec);
+        JsHintResult result = worker.process(spec);
         setDidWork(true);
 
         // TODO - this is all terribly lame. We need some proper reporting here (which means implementing Reporting).
@@ -157,9 +149,4 @@ public class JsHint extends SourceTask {
             throw new TaskExecutionException(this, new GradleException("JsHint detected errors"));
         }
     }
-
-    private RhinoWorkerSpec<JsHintResult, JsHintSpec> createWorkerSpec() {
-        return new RhinoWorkerSpec<JsHintResult, JsHintSpec>(JsHintResult.class, JsHintSpec.class, JsHintWorker.class);
-    }
-
 }
