@@ -73,19 +73,6 @@ public class ChainingModelProjection implements ModelProjection {
         return null;
     }
 
-    @Override
-    public boolean equals(Object o) {
-        if (this == o) {
-            return true;
-        }
-        if (o == null || getClass() != o.getClass()) {
-            return false;
-        }
-
-        ChainingModelProjection that = (ChainingModelProjection) o;
-        return projections.equals(that.projections);
-    }
-
     @Override
     public Optional<String> getValueDescription(MutableModelNode modelNodeInternal) {
         for (ModelProjection projection : projections) {
@@ -97,11 +84,6 @@ public class ChainingModelProjection implements ModelProjection {
         return Optional.absent();
     }
 
-    @Override
-    public int hashCode() {
-        return projections.hashCode();
-    }
-
     @Override
     public String toString() {
         return "ChainingModelProjection{projections=" + projections + '}';
