@@ -31,28 +31,35 @@ import org.gradle.jvm.JvmBinarySpec;
 import org.gradle.jvm.internal.DefaultJavaPlatformVariantAxisCompatibility;
 import org.gradle.jvm.internal.JarBinaryRenderer;
 import org.gradle.jvm.platform.JavaPlatform;
+import org.gradle.jvm.toolchain.internal.JavaInstallationProbe;
 import org.gradle.language.base.internal.model.DefaultVariantAxisCompatibilityFactory;
 import org.gradle.language.base.internal.model.VariantAxisCompatibilityFactory;
 import org.gradle.language.base.internal.model.VariantsMetaData;
 import org.gradle.language.base.internal.resolve.LocalComponentResolveContext;
 import org.gradle.model.internal.manage.schema.ModelSchemaStore;
+import org.gradle.process.internal.ExecActionFactory;
 
 public class PlatformJvmServices implements PluginServiceRegistry {
+    @Override
     public void registerGlobalServices(ServiceRegistration registration) {
         registration.add(JarBinaryRenderer.class);
         registration.add(VariantAxisCompatibilityFactory.class, DefaultVariantAxisCompatibilityFactory.of(JavaPlatform.class, new DefaultJavaPlatformVariantAxisCompatibility()));
     }
 
+    @Override
     public void registerBuildSessionServices(ServiceRegistration registration) {
     }
 
+    @Override
     public void registerBuildServices(ServiceRegistration registration) {
         registration.addProvider(new BuildScopeServices());
     }
 
+    @Override
     public void registerGradleServices(ServiceRegistration registration) {
     }
 
+    @Override
     public void registerProjectServices(ServiceRegistration registration) {
     }
 
@@ -60,6 +67,10 @@ public class PlatformJvmServices implements PluginServiceRegistry {
         LocalLibraryDependencyResolverFactory createResolverProviderFactory(ProjectModelResolver projectModelResolver, ServiceRegistry registry) {
             return new LocalLibraryDependencyResolverFactory(projectModelResolver, registry);
         }
+
+        JavaInstallationProbe createJavaInstallationProbe(ExecActionFactory factory) {
+            return new JavaInstallationProbe(factory);
+        }
     }
 
     public static class LocalLibraryDependencyResolverFactory implements ResolverProviderFactory {
