@@ -30,8 +30,8 @@ import org.gradle.api.tasks.testing.Test;
 import org.gradle.internal.Factory;
 import org.gradle.internal.TrueTimeProvider;
 import org.gradle.internal.progress.OperationIdGenerator;
-import org.gradle.messaging.actor.ActorFactory;
-import org.gradle.process.internal.WorkerProcessFactory;
+import org.gradle.internal.actor.ActorFactory;
+import org.gradle.process.internal.worker.WorkerProcessFactory;
 
 /**
  * The default test class scanner factory.
@@ -80,6 +80,6 @@ public class DefaultTestExecuter implements TestExecuter {
 
         final Object testTaskOperationId = OperationIdGenerator.generateId(testTask);
 
-        new TestMainAction(detector, processor, testResultProcessor, new TrueTimeProvider(), testTaskOperationId, testTask.getPath(), String.format("Gradle Test Run %s", testTask.getPath())).run();
+        new TestMainAction(detector, processor, testResultProcessor, new TrueTimeProvider(), testTaskOperationId, testTask.getPath(), "Gradle Test Run " + testTask.getPath()).run();
     }
 }
