@@ -31,12 +31,14 @@ import org.gradle.api.internal.tasks.testing.filter.DefaultTestFilter;
 import org.gradle.api.reporting.DirectoryReport;
 import org.gradle.api.tasks.testing.Test;
 import org.gradle.api.tasks.testing.testng.TestNGOptions;
+import org.gradle.internal.Factory;
 import org.gradle.internal.TimeProvider;
 import org.gradle.internal.id.IdGenerator;
 import org.gradle.internal.reflect.Instantiator;
 import org.gradle.internal.service.ServiceRegistry;
-import org.gradle.messaging.actor.ActorFactory;
-import org.gradle.process.internal.WorkerProcessBuilder;
+import org.gradle.internal.actor.ActorFactory;
+import org.gradle.process.internal.worker.WorkerProcessBuilder;
+import org.gradle.util.DeprecationLogger;
 
 import java.io.File;
 import java.io.Serializable;
@@ -50,11 +52,16 @@ public class TestNGTestFramework implements TestFramework {
     private final DefaultTestFilter filter;
     private final TestClassLoaderFactory classLoaderFactory;
 
-    public TestNGTestFramework(Test testTask, DefaultTestFilter filter, Instantiator instantiator, ClassLoaderCache classLoaderCache) {
+    public TestNGTestFramework(final Test testTask, DefaultTestFilter filter, Instantiator instantiator, ClassLoaderCache classLoaderCache) {
         this.testTask = testTask;
         this.filter = filter;
         options = instantiator.newInstance(TestNGOptions.class, testTask.getProject().getProjectDir());
-        options.setAnnotationsOnSourceCompatibility(JavaVersion.toVersion(testTask.getProject().property("sourceCompatibility")));
+        DeprecationLogger.whileDisabled(new Runnable() {
+            @Override
+            public void run() {
+                options.setAnnotationsOnSourceCompatibility(JavaVersion.toVersion(testTask.getProject().property("sourceCompatibility")));
+            }
+        });
         conventionMapOutputDirectory(options, testTask.getReports().getHtml());
         detector = new TestNGDetector(new ClassFileExtractionManager(testTask.getTemporaryDirFactory()));
         classLoaderFactory = new TestClassLoaderFactory(classLoaderCache, testTask);
@@ -73,9 +80,20 @@ public class TestNGTestFramework implements TestFramework {
         verifyConfigFailurePolicy();
         verifyPreserveOrder();
         verifyGroupByInstances();
-        options.setTestResources(testTask.getTestSrcDirs());
+        DeprecationLogger.whileDisabled(new Runnable() {
+            @Override
+            public void run() {
+                options.setTestResources(testTask.getTestSrcDirs());
+            }
+        });
         List<File> suiteFiles = options.getSuites(testTask.getTemporaryDir());
-        return new TestClassProcessorFactoryImpl(options.getOutputDirectory(), new TestNGSpec(options, filter), suiteFiles);
+        TestNGSpec spec = DeprecationLogger.whileDisabled(new Factory<TestNGSpec>() {
+            @Override
+            public TestNGSpec create() {
+                return new TestNGSpec(options, filter);
+            }
+        });
+        return new TestClassProcessorFactoryImpl(this.options.getOutputDirectory(), spec, suiteFiles);
     }
 
     private void verifyConfigFailurePolicy() {
