@@ -17,6 +17,7 @@
 package org.gradle.tooling.model.gradle;
 
 import org.gradle.api.Incubating;
+import org.gradle.tooling.model.ProjectIdentifier;
 import org.gradle.tooling.model.DomainObjectSet;
 import org.gradle.tooling.model.Model;
 
@@ -28,6 +29,14 @@ import org.gradle.tooling.model.Model;
 @Incubating
 public interface ProjectPublications extends Model {
 
+    /**
+     * Returns the identifier for the Gradle project that these invocations originate from.
+     *
+     * @since 2.13
+     */
+    @Incubating
+    ProjectIdentifier getProjectIdentifier();
+
     /**
      * Returns the publications for this project.
      */
